@@ -8,7 +8,7 @@ SERVICE = 'profiles'
 
 class IdentificationProcessReadContract(Contract):
     id = serializers.IntegerField(min_value=1)
-    updated = serializers.DateField()
+    updated = serializers.DateTimeField()
     user_id = serializers.IntegerField(min_value=1)
     result = serializers.ChoiceField(choices=result.RESULT_CHOICES)
     comment = serializers.CharField(max_length=1024, allow_blank=True)
